@@ -14,6 +14,9 @@ openDeleteDocument = function () {
  * @param result_id
  */
 delete_document = function(){
+    var icon = $("[id^='delete-document-yes'] > i").attr("class");
+    // Show loading spinner
+    showSpinner($("[id^='delete-document-yes'] > i"))
 	$.ajax({
         url : dashboardDeleteDocumentUrl,
         type : "POST",
@@ -27,12 +30,15 @@ delete_document = function(){
 
         },
 		success: function(data){
-		        location.reload(true);
+            location.reload();
 	    },
         error:function(data){
-            var error_message = JSON.parse(data.responseText);
-            $.notify(error_message.message);
+            let error_message = JSON.parse(data.responseText);
+            $.notify(error_message.message, "danger");
         }
+    }).always(function() {
+        // get old button icon
+        hideSpinner($("[id^='delete-document-yes'] > i"), icon)
     });
 };
 
