@@ -23,7 +23,10 @@ from core_explore_common_app.components.abstract_persistent_query.models import
     AbstractPersistentQuery,
 )
 from core_main_app.access_control.exceptions import AccessControlError
-from core_main_app.commons.exceptions import DoesNotExist, ModelError
+from core_main_app.commons.exceptions import (
+    DoesNotExist,
+    NotUniqueError,
+)
 from core_main_app.components.blob import api as blob_api
 from core_main_app.components.lock import api as lock_api
 from core_main_app.components.workspace import api as workspace_api
@@ -264,7 +267,7 @@ def _delete_workspace(request, workspace_ids):
             workspace_ids, request.user.is_superuser, request.user.id
         )
     except Exception as exception:
-        messages.add_message(request, messages.INFO, str(exception))
+        messages.add_message(request, messages.ERROR, str(exception))
         return HttpResponse(
             json.dumps({}), content_type="application/javascript"
         )
@@ -290,7 +293,7 @@ def _delete_file(request, blob_ids):
     try:
         list_blob = _get_blobs(blob_ids, request.user)
     except Exception as exception:
-        messages.add_message(request, messages.INFO, str(exception))
+        messages.add_message(request, messages.ERROR, str(exception))
         return HttpResponse(
             json.dumps({}), content_type="application/javascript"
         )
@@ -299,11 +302,11 @@ def _delete_file(request, blob_ids):
         for blob in list_blob:
             blob_api.delete(blob, request.user)
         messages.add_message(
-            request, messages.INFO, "File deleted with success."
+            request, messages.SUCCESS, "File deleted with success."
         )
     except Exception:
         messages.add_message(
-            request, messages.INFO, "A problem occurred while deleting."
+            request, messages.ERROR, "A problem occurred while deleting."
         )
 
     return HttpResponse(json.dumps({}), content_type="application/javascript")
@@ -321,7 +324,7 @@ def _delete_form(request, form_ids):
     try:
         list_form = _get_forms(form_ids, request.user)
     except Exception as exception:
-        messages.add_message(request, messages.INFO, str(exception))
+        messages.add_message(request, messages.ERROR, str(exception))
         return HttpResponse(
             json.dumps({}), content_type="application/javascript"
         )
@@ -331,12 +334,12 @@ def _delete_form(request, form_ids):
             curate_data_structure_api.delete(form, request.user)
         messages.add_message(
             request,
-            messages.INFO,
+            messages.SUCCESS,
             get_form_label().capitalize() + " deleted with success.",
         )
     except Exception:
         messages.add_message(
-            request, messages.INFO, "A problem occurred while deleting."
+            request, messages.ERROR, "A problem occurred while deleting."
         )
 
     return HttpResponse(json.dumps({}), content_type="application/javascript")
@@ -355,7 +358,7 @@ def _delete_record(request, data_ids):
     try:
         list_data = _get_data(data_ids, request.user)
     except Exception as exception:
-        messages.add_message(request, messages.INFO, str(exception))
+        messages.add_message(request, messages.ERROR, str(exception))
         return HttpResponse(
             json.dumps({}), content_type="application/javascript"
         )
@@ -378,12 +381,12 @@ def _delete_record(request, data_ids):
             data_api.delete(data, request.user)
         messages.add_message(
             request,
-            messages.INFO,
+            messages.SUCCESS,
             get_data_label().capitalize() + " deleted with success.",
         )
     except Exception:
         messages.add_message(
-            request, messages.INFO, "A problem occurred while deleting."
+            request, messages.ERROR, "A problem occurred while deleting."
         )
 
     return HttpResponse(json.dumps({}), content_type="application/javascript")
@@ -419,7 +422,7 @@ def _delete_query(request, query_ids):
         )
 
     except Exception as exception:
-        messages.add_message(request, messages.INFO, str(exception))
+        messages.add_message(request, messages.ERROR, str(exception))
         return HttpResponse(
             json.dumps({}), content_type="application/javascript"
         )
@@ -430,12 +433,12 @@ def _delete_query(request, query_ids):
 
         messages.add_message(
             request,
-            messages.INFO,
+            messages.SUCCESS,
             " Query deleted with success.",
         )
     except Exception:
         messages.add_message(
-            request, messages.INFO, "A problem occurred while deleting."
+            request, messages.ERROR, "A problem occurred while deleting."
         )
 
     return HttpResponse(json.dumps({}), content_type="application/javascript")
@@ -602,8 +605,10 @@ def edit_record(request):
 
     try:
         # Check if a curate data structure already exists
-        curate_data_structure = curate_data_structure_api.get_by_data_id(
-            data.id, request.user
+        curate_data_structure = (
+            curate_data_structure_api.get_by_data_id_and_user(
+                data.id, request.user
+            )
         )
     except DoesNotExist:
         try:
@@ -631,7 +636,7 @@ def edit_record(request):
             curate_data_structure = curate_data_structure_api.upsert(
                 curate_data_structure, request.user
             )
-        except ModelError:
+        except NotUniqueError:
             message = Message(
                 messages.ERROR,
                 f"Unable to edit the {get_data_label()}. Please check that a {get_form_label()}"
@@ -641,6 +646,16 @@ def edit_record(request):
                 json.dumps({"message": message.message, "tags": message.tags}),
                 content_type="application/json",
             )
+        except Exception:
+            message = Message(
+                messages.ERROR,
+                f"An unexpected error occurred. Unable to edit the {get_data_label()}.",
+            )
+            return HttpResponseBadRequest(
+                json.dumps({"message": message.message, "tags": message.tags}),
+                content_type="application/json",
+            )
+
     except Exception:
         message = Message(messages.ERROR, "A problem occurred while editing.")
         return HttpResponseBadRequest(
