@@ -3,15 +3,13 @@
 import copy
 import math
 
+from django.conf import settings as conf_settings
 from django.contrib import messages
-from django.contrib.auth import update_session_auth_hash
 from django.contrib.auth.decorators import login_required
-from django.contrib.auth.forms import PasswordChangeForm
 from django.core.exceptions import ObjectDoesNotExist
 from django.db import IntegrityError
 from django.http.response import HttpResponseRedirect
-from django.shortcuts import redirect
-from django.urls import reverse, reverse_lazy
+from django.urls import reverse
 
 import core_main_app.components.data.api as workspace_data_api
 from core_explore_common_app.components.abstract_persistent_query import (
@@ -22,6 +20,7 @@ from core_explore_common_app.components.abstract_persistent_query.models import
 )
 from core_explore_common_app.views.user.views import ResultQueryRedirectView
 from core_main_app.access_control.exceptions import AccessControlError
+from core_main_app.commons.exceptions import DoesNotExist
 from core_main_app.components.blob import api as blob_api, utils as blob_utils
 from core_main_app.components.data import api as data_api
 from core_main_app.components.template import api as template_api
@@ -43,7 +42,7 @@ from core_main_app.utils.rendering import render
 from core_main_app.views.admin.forms import EditProfileForm
 from core_main_app.views.common.ajax import EditTemplateVersionManagerView
 from core_main_app.views.common.views import CommonView
-from core_main_app.views.user.forms import WorkspaceForm
+from core_main_app.views.user.forms import WorkspaceForm, BlobFileForm
 
 if "core_curate_app" in INSTALLED_APPS:
     import core_curate_app.components.curate_data_structure.api as curate_data_structure_api
@@ -58,7 +57,7 @@ from core_dashboard_common_app import settings
 from core_dashboard_common_app.views.common.forms import ActionForm, UserForm
 
 
-@login_required(login_url=reverse_lazy("core_main_app_login"))
+@login_required
 def home(request):
     """Home page.
 
@@ -74,7 +73,7 @@ def home(request):
     )
 
 
-@login_required(login_url=reverse_lazy("core_main_app_login"))
+@login_required
 def my_profile(request):
     """User's profile information page.
 
@@ -86,11 +85,14 @@ def my_profile(request):
     return render(
         request,
         dashboard_constants.DASHBOARD_PROFILE_TEMPLATE,
-        context={"page_title": "My Profile"},
+        context={
+            "page_title": "My Profile",
+            "ENABLE_SAML2_SSO_AUTH": conf_settings.ENABLE_SAML2_SSO_AUTH,
+        },
     )
 
 
-@login_required(login_url=reverse_lazy("core_main_app_login"))
+@login_required
 def my_profile_edit(request):
     """Edit the profile.
 
@@ -102,7 +104,7 @@ def my_profile_edit(request):
     if request.method == "POST":
         form = _get_edit_profile_form(
             request=request,
-            url=dashboard_constants.DASHBOARD_PROFILE_EDIT_TEMPLATE,
+            template=dashboard_constants.DASHBOARD_PROFILE_EDIT_TEMPLATE,
         )
         if form.is_valid():
             user = request.user
@@ -130,7 +132,7 @@ def my_profile_edit(request):
 
             messages.add_message(
                 request,
-                messages.INFO,
+                messages.SUCCESS,
                 "Profile information edited with success.",
             )
             return HttpResponseRedirect(reverse("core_dashboard_profile"))
@@ -152,12 +154,12 @@ def my_profile_edit(request):
     )
 
 
-def _get_edit_profile_form(request, url, data=None):
+def _get_edit_profile_form(request, template, data=None):
     """Edit the profile.
 
     Args:
         request
-        url
+        template
         data
 
     Returns:
@@ -169,7 +171,7 @@ def _get_edit_profile_form(request, url, data=None):
         message = "A problem with the form has occurred."
         return render(
             request,
-            url,
+            template,
             context={"action_result": message, "page_title": "Error"},
         )
 
@@ -195,68 +197,6 @@ def _error_while_saving(request, form):
     )
 
 
-class UserDashboardPasswordChangeFormView(CommonView):
-    """User Dashboard Password Change Form View"""
-
-    success_url = "core_main_app_homepage"
-    template_name = "core_dashboard_common_app/my_profile_change_password.html"
-
-    def get(self, request, *args, **kwargs):
-        """get password form
-
-        Args:
-            request:
-            args:
-            kwargs:
-
-        Returns:
-
-        """
-
-        form = PasswordChangeForm(request.user)
-        return render(
-            request,
-            self.template_name,
-            context={"form": form, "page_title": "Change Password"},
-            assets=self._get_assets(),
-        )
-
-    def post(self, request, *args, **kwargs):
-        """update password
-
-        Args:
-            request:
-            args:
-            kwargs:
-
-        Returns:
-
-        """
-
-        form = PasswordChangeForm(request.user, request.POST)
-        if form.is_valid():
-            user = form.save()
-            update_session_auth_hash(request, user)
-            messages.success(
-                request, "Your password was successfully updated!"
-            )
-            return redirect(self.success_url)
-
-        messages.error(request, "There are errors on the form.")
-        return render(
-            request,
-            self.template_name,
-            context={"form": form, "page_title": "Change Password"},
-            assets=self._get_assets(),
-        )
-
-    @staticmethod
-    def _get_assets():
-        return {
-            "css": ["core_dashboard_common_app/common/css/password_form.css"]
-        }
-
-
 class DashboardRecords(CommonView):
     """List the records."""
 
@@ -299,7 +239,7 @@ class DashboardRecords(CommonView):
         # Data context
         try:
             results_paginator.object_list = self._format_data_context(
-                results_paginator.object_list
+                results_paginator.object_list, request.user
             )
         except Exception:
             results_paginator.object_list = []
@@ -373,15 +313,27 @@ class DashboardRecords(CommonView):
             modals=modals,
         )
 
-    def _format_data_context(self, data_list):
+    def _format_data_context(self, data_list, user):
         data_context_list = []
+
         for data in data_list:
+            forms_count = (
+                len(
+                    curate_data_structure_api.get_all_curate_data_structures_by_data(
+                        data, user
+                    )
+                )
+                if self.administration
+                else 0
+            )
             data_context_list.append(
                 {
                     "data": data,
                     "can_read": True,
                     "can_write": True,
                     "is_owner": True,
+                    "forms_count": forms_count,
+                    "form_id": self._get_form(data, user),
                     "can_change_workspace": check_if_workspace_can_be_changed(
                         data
                     ),
@@ -389,6 +341,14 @@ class DashboardRecords(CommonView):
             )
         return data_context_list
 
+    def _get_form(self, data, user):
+        try:
+            return curate_data_structure_api.get_by_data_id_and_user(
+                data.id, user
+            ).id
+        except DoesNotExist:
+            return None
+
     def _get_assets(self):
         assets = {
             "css": copy.deepcopy(dashboard_constants.CSS_COMMON),
@@ -419,6 +379,14 @@ class DashboardRecords(CommonView):
                     "path": "core_dashboard_common_app/common/js/list/open_record.raw.js",
                     "is_raw": True,
                 },
+                {
+                    "path": "core_dashboard_common_app/common/js/list/delete_data_draft.js",
+                    "is_raw": False,
+                },
+                {
+                    "path": "core_dashboard_common_app/common/js/list/open_form.raw.js",
+                    "is_raw": True,
+                },
                 {
                     "path": dashboard_constants.JS_COMMON_FUNCTION_CHANGE_OWNER,
                     "is_raw": False,
@@ -532,7 +500,10 @@ class DashboardFiles(CommonView):
                     "user": username,
                     "date": file.creation_date,
                     "file": file,
-                    "url": blob_utils.get_blob_download_uri(file, request),
+                    "url": f"{reverse('core_main_app_blob_detail')}?id={file.id}",
+                    "download_url": blob_utils.get_blob_download_uri(
+                        file, request
+                    ),
                     "can_change_workspace": check_if_workspace_can_be_changed(
                         file
                     ),
@@ -542,6 +513,7 @@ class DashboardFiles(CommonView):
 
         # Add user_form for change owner
         user_form = UserForm(request.user)
+        file_upload_form = BlobFileForm()
         context = {
             "administration": self.administration,
             "number_total": files.count(),
@@ -550,6 +522,7 @@ class DashboardFiles(CommonView):
             "document": dashboard_constants.FUNCTIONAL_OBJECT_ENUM.FILE.value,
             "template": dashboard_constants.DASHBOARD_FILES_TEMPLATE_TABLE,
             "menu": self.administration,
+            "file_upload_form": file_upload_form,
             "share_pid_button": "core_linked_records_app"
             in settings.INSTALLED_APPS,
             "pagination": _get_pagination_document(
@@ -574,6 +547,7 @@ class DashboardFiles(CommonView):
 
         modals = [
             "core_main_app/user/workspaces/list/modals/assign_workspace.html",
+            "core_main_app/user/blob/list/modals/file_upload.html",
             dashboard_constants.MODALS_COMMON_DELETE,
             dashboard_constants.MODALS_COMMON_CHANGE_OWNER,
         ]
@@ -581,6 +555,10 @@ class DashboardFiles(CommonView):
         assets = {
             "css": dashboard_constants.CSS_COMMON,
             "js": [
+                {
+                    "path": "core_dashboard_common_app/user/js/list/modals/upload_file.js",
+                    "is_raw": False,
+                },
                 {
                     "path": "core_dashboard_common_app/user/js/init.raw.js",
                     "is_raw": True,
@@ -612,7 +590,7 @@ class DashboardFiles(CommonView):
             ],
         }
 
-        if "core_file_preview_app" in INSTALLED_APPS:
+        if "core_file_preview_app" in conf_settings.INSTALLED_APPS:
             assets["js"].extend(
                 [
                     {
@@ -1301,6 +1279,16 @@ class DashboardWorkspaceRecords(CommonView):
 
         assets = self._get_assets()
 
+        if self.administration and workspace.owner:
+            context.update(
+                {
+                    "owner": user_api.get_user_by_id(workspace.owner).username,
+                    "owner_change_url": reverse(
+                        "admin:auth_user_change", args=[workspace.owner]
+                    ),
+                }
+            )
+
         # Set page title
         context.update({"page_title": "Dashboard"})
 
@@ -1575,14 +1563,6 @@ class DashboardQueries(CommonView):
                     "path": "core_dashboard_common_app/user/js/list/modals/edit_persistent_query.js",
                     "is_raw": False,
                 },
-                {
-                    "path": "core_main_app/libs/highlight/11.0.0/js/highlight.min.js",
-                    "is_raw": False,
-                },
-                {
-                    "path": "core_main_app/libs/highlight/11.0.0/js/init_highlight.js",
-                    "is_raw": False,
-                },
             ],
         }
         assets["css"].append(
@@ -1591,9 +1571,6 @@ class DashboardQueries(CommonView):
         assets["css"].append(
             "core_dashboard_common_app/common/css/content_query.css"
         )
-        assets["css"].append(
-            "core_main_app/libs/highlight/11.0.0/css/atom-one-light.css"
-        )
         assets["css"].append("core_main_app/common/css/share_link.css"),
 
         # Admin
